@@ -98,7 +98,7 @@ KRenameImpl::KRenameImpl( QWidget* p, KMenuBar* m, QPushButton* finish )
     plugin = PluginLoader::instance();
     helpDialogData = new HelpDialogData();
     // Maybe parent instead of 0 but might crash when switching from wizard to tab mode
-    helpDialog = new HelpDialog( helpDialogData, 0, false );
+    helpDialog = new HelpDialog( helpDialogData, NULL, NULL, false );
 
     m_switching = false;
     
